bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 17. Aventiure
___________________________________________________ #### <Wie Sifrit bechlaget vn– begraben wart>
| ### o biten si der naht vnd fuoren vber Rin ### von helden kvnde nimmer wirs geiaget sin ### ein tier daz si da sluogen daz weinende edeliu wip ### ia mvosten sin enkelten vil guoter wigande lip
###### 944 | ### Von grozer vbermvoten mvget ir horen sagen ### vnde von islicher rache ez hiez Hagne tragen ### Sifriden also toten von Niblunge lant ### fvr eine kemenaten da er Kriemhilde vant
###### 945 | ### Er hiez in tovgenliche legen an div ture ### daz si in da vinden solde so si gienge herfure ### hin ce mettine ê daz ez wurde tac [39a] ### der div frovwe <Chriemhilt> vil selten eine verlach
###### 946 | ### Man lute da ze dem mvnster nach gewoneheit ### Kriemhilt div vil schoene wacte mænige meit ### ein lieht bat si ir bringen vn– ovch ir gewant ### do kom ein kamerere da er Sifriden vant
###### 947 | ### Er sach in bluotes roten sin wat was elliv naz ### daz er sin herre were nie enwesser daz ### hin der kemenaten daz lieht truoch an der hant ### bi dem vil leidiv mære vrovwe Kriemhilt ervant
###### 948 | ### Do si mit ir vrovwen ce kirche wolde gan ### do sprach der kamerere vrowe ir svlt stille stan ### ez lit vor dem gademe ein riter tot erslagen ### ovwe sprach vro Kriemhilt waz wil du solcher mere sagen
###### 949 | ### E si rehte erfunde daz ez were ir man ### an die Hagnen vrage denken si began ### wie er solde in fristen erst do wart ir leit ### von ir was allen vrovden mit sime tode widerseit
###### 950 | ### Si seic zvo der erden daz si niht ensprach ### die schoenen vrovdelosen ligen man do sach ### Kriemhilde iamer wart vnmazen groz ### do schrei si nach unkreften daz al div kemenate erdoz
###### 951 | ### Do sprach daz gesinde waz ob ez ist ein gast ### daz bluot ir uz dem mvnde vor herzen iamer brast ### do sprach si nein ez ist Sifrit min vil lieber man ### ez hat geraten Brunhilt daz ez Hagne hat getan
###### 952 | ### Div vrowe bat sich wisen da si den helt vant ### si huop sin schoene hovbet mit ir vil wizen hant ### swie rot ez was von bluote si het in schier erkant ### do lac vil iemerliche der helt von Niderlant
###### 953 | ### Do rief truorechlichen di kvneginne milt ### we mir dises leides nu ist dir doch din schilt ### mit swerten niht verhovwen dv bist ermorderot ### wes ich wer ez het getan ich riete im immer sinen tot
###### 954 | ### Allez ir gesinde klagete vnde scre ### mit ir lieben vrovwen wand in was vil we ### vmb ir edelen herren der da was verlorn ### gerochen hete Hagene vil vbele Brunhilde zorn
###### 955 | ### Do sprach div iamerhafte ir sult hine gan ### vn– weket harte balde die Sifrides man ### ir svlt ovch Sigmunde minen iamer sagen ### ob er mir helfen welle den kuenen Sifriden klagen
###### 956 | ### Do lief ein bote balde da er si ligen vant ### Sifrides helde von Niblvnge lant ### mit den vil leiden mæren ir vrovde er in benam ### si woldenz niht gelovben ê man daz weinen vernam
###### 957 | ### Der bote kom ovch schiere da der kvnich lac ### Sigmvnt der herre des slafes niene phlac ### ich wene sin herze im seite daz im was geschehen ### daz er Sifriden nimmer solde <mer> gesehen
###### 958 | ### Wachet herre Sigmvnt mich bat nach iv gan [39b] ### Kriemhilt min frowe der ist ein leit getan ### daz ir vor allen leiden an ir herze gat ### daz sult ir klagen helfen wan ez sere ivch bestat
###### 959 | ### Vf rihte sich do Sigmunt er sprach waz sint div leit ### der schoenen Kriemhilde so dv hast geseit ### er sprach mit weinen ich kan ivz niht verdagen ### ia ist von Niderlanden der kuene Sifrit erslagen
###### 960 | ### Do sprach der kvnich Sigmvnt lat daz schinphen sin ### vn– also boesiv mere durch den willen min ### daz ir saget ieman daz er si erslagen ### wan daz kvnd ich nimmer vor mime tode verklagen
###### 961 | ### Welt irz niht gelovben daz ir mich horet sagen ### so vernemet selbe Kriemhilde klagen ### vn– allez ir gesinde den Sifrides tot ### vil sere srach do <Sigmvnt> des gie im werlichen not
###### 962 | ### Mit hvndert siner manne er von den betten spranch ### si zvchten zuo den handen div scharphen wafen lanch ### si liefen zuo den wuoffen iemerlichen dan ### do komen tvsent reken des kvenen <Sifrides> man
###### 963 | ### Do si so iamerliche die frovwen horten klagen ### do wanden svmeliche si solden kleider tragen ### ia mohten si der sinne vor iamer niht gehaben ### in wart mikel swere in ir herze begraben
###### 964 | ### Do kom der kvnich Sigmvnt da er Kriemhilde vant ### er sprach owe der reise here in dice lant ### wer hat mich mines kindes vnd ivch des iwren man ### bi also guoten vrivnden alsvs mortlich getan
###### 965 | ### Sold ich den bekennen sprach daz vil edel wip ### holt wurde im nimmer min herze noch min lip ### ich riete im alse leides daz al die frivnde sin ### von minen schvlden mvozen immer klagende sin
###### 966 | ### Sigmvnt der herre den fursten vmbesloz ### do wart von sinen vrivnden der iamer also groz ### daz von den starken wuofe palas vnde sal ### vnd din stat ze Wormeze ce beiden siten lute <ersal >
###### 967 | ### Do enkvnde nieman trosten Sifrides wip ### man zoch vz den kleideren sinen schoenen lip ### vnde wuosch im sine wunde man leite in vf den re ### do was sinen lûten von starkern iamer vil we
###### 968 | ### Ez spraken sine reken vz Niblvnge lant ### in sol immer reken mit willen vnser hant ### er ist in disem huse der ez hat getan ### do ilten sich wafenen alle Sifrides man
###### 969 | ### Die vz erwelten degne mit schilden komen dar ### einlif hvndert reken die hete an siner schar ### Sigmvnt der rike sines svnes tot ### wold in gerne reken als im sin friwe daz gebot
###### 970 | ### Si wessen wen si solden mit strite do bestan ### si enteten Gvnthern vn– ovch sine man ### mit den her Sifrit an daz geieide reit [40a] ### Kiemhilt sach si gewafent daz was ir ander herzeleit
###### 971 | ### Swie michel wer ir iamer vn– swie starch ir not ### doch vorhte si harte der Niblvnge tot ### von ir bruoder mannen daz si ez vnderstuont ### si warende si guotliche so vrivnde liebe frivnde tuont
###### 972 | ### Ez sprach div iamers riche min her Sigmvnt ### wes welt ir beginnen iv ist niht rehte kvnt ### ia hat kvnich Gvnther so manigen kuenen man ### ir welt iv alle vliesen welt ir die reken bestan
###### 973 | ### Mit vf erbvnden schilden was in ce strite not ### div edel kvnginne si bat vnd ovch gebot ### daz ez miden solden die reken vil gemeit ### daz wolden si niht lazen daz do ir herze vol durchsneit
###### 974 | ### Si sprach min her Sigmvnt ir sultez lazen stan ### vnz ez sich baz fuege so wil ich minen man ### immer mit iv reken der mir in hat benomen ### wird ich des bewiset ez muoz im schedlichen komen
###### 975 | ### Ez ist der vbermuoten hie bi Rine vil ### da von ich iv des strites raten niht enwil ### si habent wider einen ie wol drizech man ### gote laze in gelingen alse si vmb vns gedienet han
###### 976 | ### Ir svlt hie beliben vnd dolt mit mir div leit ### vnz ez tagen begvnde ir helde vil gemeit ### so helfet mir beserken minen lieben man ### do spraken die degne vrowe liep daz si getan
###### 977 | ### Iv enkvnde nieman daz wunder vol sagen ### von rittern vn von vrovwen wie man die horte clagen ### so daz man des wuofes wart in der stat geware ### die edelen burgere komen gahende dare
###### 978 | ### Si klagten mit den gesten wan in was harte leit ### Sifrides schvlde in waren niht geseit ### durk was der edel reke verlos da sinen lip ### do weinden mit den vrovwen der guoten burgere wip
###### 979 | ### Smide hiez man gahen wurken einen sarch ### von silber vnd von golde michel vn– starch ### vn– hiez in vaste spengen mit stale der was guot ### do was al den luten harte truorich der mvot
###### 980 | ### Div naht was ergangen man seite ez wolde tagen ### do hiez div edel vrovwe zuo dem mvnster tragen ### Sifrit den herren ir vil lieben man ### swaz er da frivnde hete die sach man weininde gan
###### 981 | ### Do sin zen mvnster brahten wie vil da gloken klanc ### do horte man allenthalben maniges phaphen sanch ### do kom der kvnich Gvnther dar mit sinen man ### vn– ovch der grimme Hagene daz wære bezzer verlan
###### 982 | ### Er sprach liebiv swester we der leide din ### daz wir niht mohten ane so grozes schades sin ### wir muozen in mer klagen Sifrides lip ### daz tuot ir ane schvlde sprach daz iamerafte wip
###### 983 | ### Wer iv darvmbe leide so wer ez niht geschehen ### ir hetet min vergezzen des mag ich wol iehen [40b] ### da ich da wa cheiden vn– min lieber man ### ei wolde got der wer ez selber mir getan
###### 984 | ### Si buten vaste ir logen Kriemhilde begvnde iehen ### swelher si vnschuldet der laze daz besehen ### der sol zuo der bare vor den lvten gan ### da mach man die warheit harte schiere bi versten
###### 985 | ### Daz ist ein michel wunder dike ez noch geschihet ### swa man den mortmeilen bi den toten sihet ### so bluotent im die wunden sam ovch da gesach ### da von man die schulde da ze Hagenen gesach
###### 986 | ### Die wunden fluzen sere alsam si taten ê ### die ê da sere klagten des wart nv michel me ### do sprach kvnich Gvnther ich wilz ivch wizzen lan ### in sluogen schachere Hagene hat ez niht getan
###### 987 | ### Mir sint die schachere sprach si vil wol bechant ### nv laze ez got <erreken> von siner vrivnde hant ### Gunther vn– Hagne ia habet irz getan ### die Sifrides degne heten do zuo strite wan
###### 988 | ### Kriemhilt twanc groz iamer zuo der <selben> not ### komen do die beide da si in funden tot ### Gernot ir bruoder vnd Giselher daz kint ### mit triwen si in klageten ir ovgen wurden nazzer blint
###### 989 | ### Si weinden innerclike Kriemhilde man ### man wolde messe singen zuo dem mvnster <dan> ### giengen allenthalben man vn– wip ### die sint doch lihte enbarn di weinende Sifrides lip
###### 990 | ### Gernot vn– Giselher sprachen swester min ### nu troeste dich nach tode als ez idoch mvoz sin ### wir wellen dichs ergecen die wile wir leben ### do kunde ir nieman trost neheinen gegeben
###### 991 | ### Sin sarch was bereitet wol vmb mitten tac ### man huop in von der bare da er ufe lac ### in wolde noch diu frowe lazen nihtbegraben ### des muosen al die lûte michel arbeite haben
###### 992 | ### In einen riken pfelle man den toten want ### ich wæne man da iemen ane weinen vant ### do chlagte herzenliche vote ein edel wip ### vnd al ir ingesinde Sifrides wætlichen lip
###### 993 | ### Do man gehorte daz man zem mvnster sanch ### vn– in besarket hete do huop sich groz gedranch ### durch willen siner sele waz man opfers truoc ### her hete bi den vienden doch guoter vrivnde genuoc
###### 994 | ### Kriemhilt div arme <zir> kamæreren sprach ### ir svlt durch min liebe liden vngemach ### die im guotes gunnen vnd mir wesen holt ### durch Sifrides sele sol man teilen sin golt
###### 995 | ### Dehein kint was so kleine daz wizze mohte haben ### ez muoze gen ce opher ê er wurde begraben ### wol hundert messe man des tages sanch ### von Sifrides frivnden wart do groz gedranch
###### 996 | ### Do man het gesvngen daz volch sich huop dan [41a] ### do sprach vro Kriemhilt ir sult mich eine lan ### heint mich wachen den vz erwelten degen ### er ist an sime libe al min vrovde gelegen
###### 997 | ### Dri naht vnd dri tage wil ich in lazen stan ### vnz ich mich geniete mins vil lieben man ### waz ob got gebivtet daz mich ovch nimet der tot ### so wer wol verendet min armer Kriemhilde not
###### 998 | ### Ze herbergen giengen die lûte von der stat ### pfaffen unde muniche si beliben bat ### vnd allez sin gesinde daz des heldes phlac ### si heten naht vil arge vnd vil mvolichen tac
###### 999 | ### An ezzen vnd an trinken beleib da manich man ### die ez nemen wolden den wart daz kvnt getan ### daz man ins den vollen gebe daz schuof er Sigmvnt ### do was den Niblungen vil michel arebeite kvnt
###### 1000 | ### Swaz man vant der armen die es niht mohten han ### die hiez man doch zem opher mit golde gan ### vz sin selbes kamer do er niht solde leben ### vmb sine sele wart manich tusen marc gegeben
###### 1001 | ### Urbor vf der erden teiles in div lant ### swa man kloster vnd guote livte vant ### silber gap man vnde wat den armen da genvoc ### si tet dem wol geliche daz sim holden willen truoc
###### 1002 | ### An dem dritten morgen ce rehter messezit ### so was bi dem mvnster der krihhof also wit ### von den lantluten weinens also vol ### si dienden im nach tode als man lieben vrivnden sol
###### 1003 | ### In den tagen vieren man hat geseit daz ### ce drizech tvsent marken oder dannoch baz ### wart durch sin sele den armen da gegeben ### do was gelegen ringe sin groziv schoene vn– ovch sin leben
###### 1004 | ### Do gote wart gedient vnd man vol gesanc ### mit vngefuegem leide vil des volkes ranc ### man hiez in uz den mvnster zuo dem grabe tragen ### man vant da niht anders wan ein weinen vn– klagen
###### 1005 | ### Lute scriende daz gie mit im dan ### vro was da niemen weder wip noch man ### ê man in begruebe man sanch vn– las ### hey was guoter phaffen ze siner pevilde was
###### 1006 | ### ê ce deme grabe koeme Sifrides wip ### do ranc mit solhem iamer ir getriwer lip ### daz man si mit dem brvnnen dike da begoz ### ez was ir vngemuode vil harte vnmazlichen groz
###### 1007 | ### Ez was michel wunder daz si ie genas ### mit klage ir helfende da manich vrovwe was ### do sprach div kvnigin ir Sifrides man ### ir svlt durch iwer triwe an mir genade began
###### 1008 | ### Lat mir nach mime leide ein kleine liep geschehen ### daz ich sin schoene hovbet noch einst mvze sehen ### do bat sis also lange mit iamers sinnen starch ### daz man cebrechen muose den vil herlichen sarch [41b]
###### 1009 | ### Do brahte man die vrovwen da si in ligen vant ### si huop sin schuonez hovbet mit ir vil wizzen hant ### vnd kvste in also toten den edelen riter guot ### ir vil liehten ovgen von weinenden do bluot
###### 1010 | ### Ein iærnerlichez scheiden wart do da getan ### do truoch man si von dannen si kvnde niht gegan ### do vant man sinnelose daz herliche wip ### vor leide moht ersterben ir vil wunnechlicher lip
###### 1011 | ### Do man den edelen herren heten nv begraben ### leit ane maze sach man die alle haben ### die mit im komen waren von Niblvnge lant ### vil selten frolichen man do Sigmvnden vant
###### 1012 | ### Do was etelicher der drier tage lanc ### vor dem grozem leide niht az noch entranch ### doch mochten si dem libe so geswichen niht ### si nerten sich nach sorgen so noch genuogen geschit

<<< Übersicht <<< vorige Seite nächste Seite >>>